--- ngx_http_xslt_filter_module.c-v2	2012-04-18 22:13:53.000000000 +0200
+++ ngx_http_xslt_filter_module.c	2012-04-18 22:11:11.000000000 +0200
@@ -60,6 +60,7 @@
 
 
 typedef struct {
+    ngx_str_t                  root;
     ngx_http_xslt_dtd_t       *entities;
     ngx_array_t                sheets;       /* ngx_http_xslt_sheet_t */
     ngx_hash_t                 types;
@@ -108,6 +109,8 @@
 static void ngx_http_xslt_cleanup_stylesheet(void *data);
 static void *ngx_http_xslt_filter_create_main_conf(ngx_conf_t *cf);
 static void *ngx_http_xslt_filter_create_conf(ngx_conf_t *cf);
+static ngx_int_t ngx_http_xslt_filter_full_name(
+    ngx_http_xslt_filter_loc_conf_t *conf, ngx_cycle_t *cycle, ngx_str_t *name);
 static char *ngx_http_xslt_filter_merge_conf(ngx_conf_t *cf, void *parent,
     void *child);
 static ngx_int_t ngx_http_xslt_filter_init(ngx_conf_t *cf);
@@ -122,6 +125,13 @@
 
 static ngx_command_t  ngx_http_xslt_filter_commands[] = {
 
+    { ngx_string("xslt_root"),
+      NGX_HTTP_MAIN_CONF|NGX_HTTP_SRV_CONF|NGX_HTTP_LOC_CONF|NGX_CONF_TAKE1,
+      ngx_conf_set_str_slot,
+      NGX_HTTP_LOC_CONF_OFFSET,
+      offsetof(ngx_http_xslt_filter_loc_conf_t, root),
+      NULL },
+
     { ngx_string("xml_entities"),
       NGX_HTTP_MAIN_CONF|NGX_HTTP_SRV_CONF|NGX_HTTP_LOC_CONF|NGX_CONF_TAKE1,
       ngx_http_xslt_entities,
@@ -1002,6 +1012,41 @@
 }
 
 
+static ngx_int_t
+ngx_http_xslt_filter_full_name(ngx_http_xslt_filter_loc_conf_t *conf,
+    ngx_cycle_t *cycle, ngx_str_t *name)
+{
+    size_t len;
+    u_char *n, *p;
+
+    if (conf->root.len != 0 && name->data[0] != '/') {
+        len = conf->root.len + 1 + name->len + 1;
+
+        n = ngx_pnalloc(cycle->pool, len);
+        if (n == NULL) {
+            return NGX_ERROR;
+        }
+
+        p = ngx_cpymem(n, conf->root.data, conf->root.len);
+        p[0] = '/';
+        ngx_cpystrn(++p, name->data, name->len + 1);
+
+        ngx_pfree(cycle->pool, name->data);
+
+        name->len = len;
+        name->data = n;
+
+        return NGX_OK;
+    }
+
+    if (ngx_conf_full_name(cycle, name, 0) != NGX_OK) {
+        return NGX_ERROR;
+    }
+
+    return NGX_OK;
+}
+
+
 static char *
 ngx_http_xslt_filter_merge_conf(ngx_conf_t *cf, void *parent, void *child)
 {
@@ -1016,12 +1061,16 @@
 
     xmcf = ngx_http_conf_get_module_main_conf(cf, ngx_http_xslt_filter_module);
 
+    ngx_conf_merge_str_value(conf->root, prev->root, "");
+
     if (conf->entities == NULL) {
         conf->entities = prev->entities;
 
     }
     else {
-        if (ngx_conf_full_name(cf->cycle, &conf->entities->name, 0) != NGX_OK) {
+        if (ngx_http_xslt_filter_full_name(conf, cf->cycle,
+                                           &conf->entities->name)
+            != NGX_OK) {
             return NGX_CONF_ERROR;
         }
 
@@ -1065,7 +1114,9 @@
     } else {
         sheet = conf->sheets.elts;
         for (n = 0; n < conf->sheets.nelts; n++) {
-            if (ngx_conf_full_name(cf->cycle, &sheet[n].name, 0) != NGX_OK) {
+
+            if (ngx_http_xslt_filter_full_name(conf, cf->cycle,
+                                               &sheet[n].name) != NGX_OK) {
                 return NGX_CONF_ERROR;
             }
 